@@ -34,7 +34,9 @@ pub struct Bucket {
     pub secret_access_key: Option<String>,
     pub region: String,
     pub bucket: String,
+    #[serde(alias = "key")]
     pub path: String,
+    #[serde(alias = "params")]
     pub parameters: Box<Value>,
     pub limit: Option<usize>,
     pub skip: usize,
@@ -98,6 +100,12 @@ impl fmt::Debug for Bucket {
             .field("bucket", &self.bucket)
             .field("path", &self.path)
             .field("parameters", &self.parameters)
+            .field("limit", &self.limit)
+            .field("skip", &self.skip)
+            .field("version", &self.version)
+            .field("tags", &self.tags)
+            .field("cache_control", &self.cache_control)
+            .field("expires", &self.expires)
             .finish()
     }
 }
@@ -185,8 +193,11 @@ impl Connector for Bucket {
             return Ok(false);
         }
 
-        let actuel_path = self.path.clone().replace_mustache(*self.parameters.clone());
-        let new_path = self.path.clone().replace_mustache(new_parameters);
+        let mut actuel_path = self.path.clone();
+        actuel_path.replace_mustache(*self.parameters.clone());
+        
+        let mut new_path = self.path.clone();
+        new_path.replace_mustache(new_parameters);
 
         if actuel_path == new_path {
             return Ok(false);
@@ -210,7 +221,11 @@ impl Connector for Bucket {
     /// ```
     fn path(&self) -> String {
         match (self.is_variable(), *self.parameters.clone()) {
-            (true, params) => self.path.clone().replace_mustache(params),
+            (true, params) => {
+                let mut path = self.path.clone();
+                path.replace_mustache(params);
+                path
+            },
             _ => self.path.clone(),
         }
     }
@@ -527,9 +542,9 @@ impl async_std::io::Write for Bucket {
 
 #[derive(Debug)]
 pub struct BucketPaginator {
-    connector: Bucket,
-    paths: IntoIter<String>,
-    skip: usize,
+    pub connector: Bucket,
+    pub paths: IntoIter<String>,
+    pub skip: usize,
 }
 
 impl BucketPaginator {
@@ -668,7 +683,7 @@ impl Paginator for BucketPaginator {
     ///     Ok(())
     /// }
     /// ```
-    // # Example: With wildcard, limit and skip. List results are always returned in UTF-8 binary order
+    /// # Example: With wildcard, limit and skip. List results are always returned in UTF-8 binary order
     /// ```rust
     /// use chewdata::connector::bucket::Bucket;
     /// use chewdata::connector::Connector;
